@@ -2,4 +2,4 @@ from django.db.models import Model, IntegerField
 
 
 class Payment(Model):
-    txId = IntegerField(unique=True)
+    tx_id = IntegerField(unique=True)
